@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use base 'HTML::FormFu::Model';
 
-our $VERSION = '2.01'; # VERSION
+our $VERSION = '2.02'; # VERSION
 
 use HTML::FormFu::Util qw( _merge_hashes );
 use List::MoreUtils qw( none notall );
@@ -897,7 +897,8 @@ sub _save_columns {
             $dbic->can($accessor)
 
 # and $accessor is not a has_one or might_have rel where the foreign key is on the foreign table
-            and !$dbic->result_source->relationship_info($accessor) )
+            and !$dbic->result_source->relationship_info($accessor)
+            and !$dbic->can( 'add_to_' . $accessor ) )
         {
             $dbic->$accessor($value);
         }
@@ -1143,7 +1144,7 @@ HTML::FormFu::Model::DBIC - Integrate HTML::FormFu with DBIx::Class
 
 =head1 VERSION
 
-version 2.01
+version 2.02
 
 =head1 SYNOPSIS
 
